@@ -7,33 +7,33 @@ Anansi::Actor - A dynamic usage module definition
 
 =head1 SYNOPSIS
 
- use Anansi::Actor;
- my $object = Anansi::Actor->new(
-     PACKAGE => 'Anansi::Example',
- );
- $object->someSubroutine() if(defined($object));
+    use Anansi::Actor;
+    my $object = Anansi::Actor->new(
+        PACKAGE => 'Anansi::Example',
+    );
+    $object->someSubroutine() if(defined($object));
 
- use Anansi::Actor;
- use Data::Dumper qw(Dumper);
- my %modules = Anansi::Actor->modules();
- if(defined($modules{DBI})) {
-     Anansi::Actor->new(
-         PACKAGE => 'DBI',
-     );
-     print Data::Dumper::Dumper(DBI->available_drivers());
- }
+    use Anansi::Actor;
+    use Data::Dumper qw(Dumper);
+    my %modules = Anansi::Actor->modules();
+    if(defined($modules{DBI})) {
+        Anansi::Actor->new(
+            PACKAGE => 'DBI',
+        );
+        print Data::Dumper::Dumper(DBI->available_drivers());
+    }
 
 =head1 DESCRIPTION
 
 This is a dynamic usage module definition that manages the loading of a required
-namespace and blessing of an object of the namespace as required.  See
-L<Anansi::Singleton> for inherited methods.  Makes use of L<base>, L<Fcntl>
-L<File::Find>, L<File::Spec::Functions> and L<FileHandle>.
+namespace and blessing of an object of the namespace as required.  Uses
+L<Anansi::Singleton>, L<base>, L<Fcntl> L<File::Find>, L<File::Spec::Functions>
+and L<FileHandle>.
 
 =cut
 
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use base qw(Anansi::Singleton);
 
@@ -45,9 +45,80 @@ use FileHandle;
 
 my $ACTOR = Anansi::Actor->SUPER::new();
 
-use constant {
-    ACTOR_VARIABLE => 'example',
-};
+
+=head1 INHERITED METHODS
+
+=cut
+
+
+=head2 DESTROY
+
+Declared in L<Anansi::Singleton>.  Deprecated.
+
+=cut
+
+
+=head2 finalise
+
+Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+
+=cut
+
+
+=head2 fixate
+
+Declared in L<Anansi::Singleton>.  Deprecated.
+
+=cut
+
+
+=head2 implicate
+
+Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+
+=cut
+
+
+=head2 import
+
+Declared in L<Anansi::Class>.
+
+=cut
+
+
+=head2 initialise
+
+Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+
+=cut
+
+
+=head2 old
+
+Declared in L<Anansi::Class>.
+
+=cut
+
+
+=head2 reinitialise
+
+Declared in L<Anansi::Singleton>.  Deprecated.
+
+=cut
+
+
+=head2 used
+
+Declared in L<Anansi::Class>.
+
+=cut
+
+
+=head2 uses
+
+Declared in L<Anansi::Class>.
+
+=cut
 
 
 =head1 METHODS
@@ -55,95 +126,12 @@ use constant {
 =cut
 
 
-=head2 implicate
-
- use constant {
-     ACTOR_VARIABLE => 'some value',
- };
-
- sub implicate {
-     my ($self, $caller, $parameter) = @_;
-     if('ACTOR_VARIABLE' eq $parameter) {
-         return \ACTOR_VARIABLE;
-     }
-     try {
-         return $self->SUPER::implicate($caller, $parameter);
-     }
-     return if($@);
- }
-
-=over 4
-
-=item self I<(Blessed Hash, Required)>
-
-An object of this namespace.
-
-=item caller I<(Array, Required)>
-
-An array containing the I<package>, I<file name> and I<line number> of the caller.
-
-=item parameter I<(String, Required)>
-
-A string containing the name to import.
-
-=back
-
-Performs one module instance name import.  Called for each name to import.
-Intended to be replaced by an extending module.  Indirectly called.
-
-=cut
-
-
-sub implicate {
-    my ($self, $caller, $parameter) = @_;
-    if('ACTOR_VARIABLE' eq $parameter) {
-        return \ACTOR_VARIABLE;
-    }
-    try {
-        return $self->SUPER::implicate($caller, $parameter);
-    }
-    return if($@);
-}
-
-
-=head2 import
-
- use Anansi::Actor qw(ACTOR_VARIABLE);
-
-=over 4
-
-=item self I<(Blessed Hash, Required)>
-
-An object of this namespace.
-
-=item parameters I<(Array, Optional)>
-
-An array containing all of the names to import.
-
-=back
-
-Performs all required module name imports.  Indirectly called via an extending
-module.
-
-=cut
-
-
-sub import {
-    my ($self, @parameters) = @_;
-    my $caller = caller();
-    foreach my $parameter (@parameters) {
-        my $value = $self->implicate($caller, $parameter);
-        *{$caller.'::'.$parameter} = $value if(defined($value));
-    }
-}
-
-
 =head2 modules
 
- my %MODULES = $object->modules();
+    my %MODULES = $object->modules();
 
- use Anansi::Actor;
- my %MODULES = Anansi::Actor->modules();
+    use Anansi::Actor;
+    my %MODULES = Anansi::Actor->modules();
 
 =over 4
 
@@ -172,7 +160,10 @@ sub modules {
         if(0 < scalar(@files)) {
             my $timestamp = (split(/\./, $files[0]))[1];
             if(86400 + $timestamp < time()) {
-                unlink(@files);
+                foreach my $file (@files) {
+                    $file = File::Spec->catfile(File::Spec->splitdir(File::Spec->tmpdir()), $file);
+                    unlink($file);
+                }
                 $filename = 'Anansi-Actor.'.time();
             } else {
                 $filename = $files[0];
@@ -248,9 +239,9 @@ sub modules {
 
 =head2 new
 
- my $object = Anansi::Actor->new(
-     PACKAGE => 'Anansi::Example',
- );
+    my $object = Anansi::Actor->new(
+        PACKAGE => 'Anansi::Example',
+    );
 
 =over 4
 
@@ -267,7 +258,7 @@ Named parameters.
 =item BLESS I<(String, Optional)>
 
 The name of the subroutine within the namespace that creates a blessed object of
-the namespace.
+the namespace.  Defaults to I<"new">.
 
 =item IMPORT I<(Array, Optional)>
 
@@ -344,6 +335,9 @@ design in perl.  If for any reason you feel that it doesn't achieve these goals
 then please let me know.  I am here to help.  All constructive criticisms are
 also welcomed.
 
+=cut
+
+
 =head1 AUTHOR
 
 Kevin Treleaven <kevin I<AT> treleaven I<DOT> net>
